@@ -16,11 +16,11 @@ use strict qw(refs);
 use strict qw(subs);
 
 package Parse::ALex;
-$Parse::ALex::VERSION = '2.15';
+$Parse::ALex::VERSION = '2.16';
 use Parse::Trace;
 @Parse::ALex::ISA = qw(Parse::Trace); 
 
-use Parse::Token 2.15;	
+use Parse::Token;	
 use Parse::Template;
 
 				# Default values
